@@ -7,21 +7,29 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#include "fontchecker.h"
+
 #include <qfont.h>
 #include <qfontinfo.h>
+#ifdef Q_OS_WIN
+#include <windows.h>
+#endif
 
 #include <kio/netaccess.h>
 
-#include "fontchecker.h"
-
 bool fontChecker::checkInstalled(const QFont &font, const QString &fontPath)
 {
 	QFontInfo fi(font);
 	// Works with Steve may need some tweaking to work with other fonts
 	if (!fi.exactMatch())
 	{
-		bool success = KIO::NetAccess::copy(fontPath, "fonts:/Personal/", 0);
+#ifdef Q_OS_WIN
+    int iAdded = AddFontResourceW((LPCWSTR)fontPath.utf16());
+    return iAdded != 0;
+#else
+		bool success = KIO::NetAccess::file_copy(KUrl::fromPath(fontPath), KUrl("fonts:/Personal/"), (QWidget*)0);
 		return !success;
+#endif
 	}
 	return true;
 }
