@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Carsten Niehaus                                 *
+ *   Copyright (C) 2005, 2006 by Carsten Niehaus                                 *
  *   cniehaus@kde.org                                                      *
  *   
  *                                                                         *
@@ -21,28 +21,25 @@
 #ifndef SPECTRUMWIDGET_H
 #define SPECTRUMWIDGET_H
 
-#include <qwidget.h>
-
-#include <qpixmap.h>
+#include <QWidget>
 
 #include "spectrum.h"
 
 /**
  * @author Carsten Niehaus
- * 
  */
 class SpectrumWidget : public QWidget
 {
 	Q_OBJECT
 
 	public:
-		SpectrumWidget( QWidget *parent, const char* name = 0 );
+		SpectrumWidget( QWidget *parent );
 		
 		~SpectrumWidget(){}
 
 		void setSpectrum( Spectrum* spec ){
 			m_spectrum = spec;
-			update();
+      restart();
 		}
 
 		Spectrum* spectrum()const{
@@ -52,31 +49,12 @@ class SpectrumWidget : public QWidget
 		/**
 		 * This limits the width of the spectrum in terms of
 		 * wavelength. For example you can set it to only
-		 * show the area between 500 and 550 nm. Invalid values
-		 * will be set back to the default start- and stopvalues
+		 * show the area between 500 and 550 nm
 		 *
 		 * @param left the left border
 		 * @param right the right border
 		 */
-		void setBorders( double left, double right ){
-			//check for invalid values
-			if ( startValue < 0.0 )
-				startValue = 0.0;
-
-			if ( endValue > 800.0 )
-				endValue = 800.0;
-			
-			startValue = left;
-			endValue = right;
-
-			update();
-		}
-		
-		/**
-		 * find the nearest band. The returned value is the number
-		 * of pixel the next band is away
-		 */
-		int findNearestBand( QValueList<double>::iterator it );
+		void setBorders( double left, double right );
 
 		/**
 		 * there are several possible types.
@@ -129,10 +107,14 @@ class SpectrumWidget : public QWidget
 			return ( int ) ( ( wavelength-startValue ) * width() / ( endValue - startValue ) );
 		}
 
-		void PrepareTooltip( double wavelength );
+    /**
+     * based on the current position of the mouse-cursor the nearest
+     * peak is searched. If found, it will be emitted.
+     * 
+     * @see peakSelected
+     */
+		void findPeakFromMouseposition( double wavelength );
 
-		void showTooltip( Spectrum::band band );
-		
 		/**
 		 * @param xpos The ratio of the position relative to the width
 		 * of the widget.
@@ -152,10 +134,11 @@ class SpectrumWidget : public QWidget
 		 */
 		void wavelengthToRGB( double wavelength, int& r, int& g, int& b );
 
-		QPixmap pixmap();
-	
 	private:
-		QValueList<double> m_spectra;
+    ///(re)create startconditions
+    void restart();
+
+		QList<double> m_spectra;
 
 		SpectrumType m_type;
 
@@ -164,12 +147,9 @@ class SpectrumWidget : public QWidget
 		QPixmap m_pixmap;
 
 		bool m_showtooltip;
-
-		Spectrum::band m_band;
 		
 		void paintBands( QPainter* p );
 		void drawZoomLine( QPainter* p );
-		void drawTooltip( QPainter *p );
 		
 		/**
 		 * Draw the scale
@@ -219,6 +199,18 @@ class SpectrumWidget : public QWidget
 			update();
 		}
 
+	signals:
+    /**
+     * the minimum and maximum displayed wavelength have
+     * changed so emit the new minimum and maximum
+     */
+		void bordersChanged( int, int );
+
+    /**
+     * the user selected a peak
+     */
+    void peakSelected( Spectrum::peak * peak );
+
 	private slots:
 		void slotZoomIn();
 		void slotZoomOut();
