@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Nov 27 16:40:42 CET 2001
     copyright            : (C) 2001 by Sebastian Stein
-    email                : seb.stein@hpfsc.de
+    email                : seb.kde@hpfsc.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,18 +15,23 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "task.h"
+
 #include <math.h>
 
 #include <kdebug.h>
 
-#include "task.h"
+#include <time.h>
+
+//Added by qt3to4:
+#include <QTextStream>
 
 /** constructor of class task */
 task::task()
 {
 	srand(time(NULL));
 #ifdef DEBUG
-	kdDebug() << "constructor task" << endl;
+	kDebug() << "constructor task";
 #endif
 }
 
@@ -34,7 +39,7 @@ task::task()
 task::~task()
 {
 #ifdef DEBUG
-	kdDebug() << "destructor task" << endl;
+	kDebug() << "destructor task";
 #endif
 }
 
@@ -42,12 +47,12 @@ task::~task()
  * can be customized by the given parameters:
  * pmax_md: maximum main denominator
  * pnr_ratios: number of ratios -> pnr_ratios - 1 operations
- * padd_sub: if TRUE + and - are allowed operations
- * pmul_div: if TRUE * and / are allowed operations */
+ * padd_sub: if true + and - are allowed operations
+ * pmul_div: if true * and / are allowed operations */
 void task::create_task(unsigned int pmax_md, short pnr_ratios,
                        short padd_sub, short pmul_div)
 {
-	unsigned short max_product_length = 0;
+	unsigned int max_product_length = 0;
 	int main_denominator = 1;
 
 	/* we say that if add/sub and mul/div are not allowed we want a task
@@ -64,66 +69,66 @@ void task::create_task(unsigned int pmax_md, short pnr_ratios,
 		max_product_length = make_operation(padd_sub, pmul_div, pnr_ratios);
 
 #ifdef DEBUG
-		kdDebug() << "max_product_length: " << max_product_length << endl;
+		kDebug() << "1: max_product_length: " << max_product_length;
 #endif
 		/* later we must be able to find a main denominator;
 		 * so 2 ^ max_product_length couldn't be bigger than the max. denominator */
 	}
-	while ((unsigned int) pow(2, max_product_length) > pmax_md);
+	while ((unsigned int) pow(2.0, (double)max_product_length) > pmax_md);
 
 #ifdef DEBUG
-	kdDebug() << "max_product_length: " << max_product_length << endl;
+	kDebug() << "2: max_product_length: " << max_product_length;
 #endif
 
 	/* find a main denominator */
 	main_denominator = make_main_dn(pmax_md, max_product_length);
 
 #ifdef DEBUG
-	kdDebug() << "after make_main_dn()" << endl;
+	kDebug() << "after make_main_dn()";
 #endif
 
 	/* create the ratios' numerators */
 	make_numerators(main_denominator, pnr_ratios);
 
 #ifdef DEBUG
-	kdDebug() << "after make_numerators()" << endl;
+	kDebug() << "after make_numerators()";
 #endif
 
 	/* create the ratios' denominators */
 	make_denominators(main_denominator, pmax_md, pmul_div);
 
 #ifdef DEBUG
-	kdDebug() << "main deno: " << main_denominator << endl;
-	kdDebug() << "prim fakt: " << prim_fac_vector.size() << endl;
+	kDebug() << "main deno: " << main_denominator;
+	kDebug() << "prim fakt: " << prim_fac_vector.size();
 #endif
 
 	return;
 }
 
 /** set ratio n in the ratio_vector */
-void task::set_ratio_n(unsigned short number, int zaehler, int nenner)
+void task::set_ratio_n(unsigned short number, int numerator, int denominator)
 {
 	/* do not set something outside our vector */
 	if (number > ratio_vector.size() - 1)
 		number = 0;
-	ratio_vector[number].set_zaehler(zaehler); // set numerator
-	ratio_vector[number].set_nenner(nenner); // set denominator
+	ratio_vector[number].setNumerator(numerator); // set numerator
+	ratio_vector[number].setDenominator(denominator); // set denominator
 	return;
 }
 
 /** set ratio n in the ratio_vector */
-void task::set_ratio_n(unsigned short number, ratio bruch)
+void task::set_ratio_n(unsigned short number, ratio fraction)
 {
 	/* do not set something outside our vector */
 	if (number > ratio_vector.size() - 1)
 		number = 0;
-	ratio_vector[number].set_zaehler(bruch.get_zaehler()); // set numerator
-	ratio_vector[number].set_nenner(bruch.get_nenner()); // set denominator
+	ratio_vector[number].setNumerator(fraction.numerator()); // set numerator
+	ratio_vector[number].setDenominator(fraction.denominator()); // set denominator
 	return;
 }
 
 /** returns the ratio given by number from the ratio_vector */
-ratio task::get_ratio_n(unsigned short number)
+ratio task::get_ratio_n(unsigned short number) const
 {
 	/* do not set something outside our vector */
 	if (number > ratio_vector.size() - 1)
@@ -142,7 +147,7 @@ void task::set_op_n(unsigned short number, short operation)
 }
 
 /** returns the operation given by number from the op_vector */
-short task::get_op_n(unsigned short number)
+short task::get_op_n(unsigned short number) const
 {
 	/* do not set something outside our vector */
 	if (number > op_vector.size() - 1)
@@ -158,9 +163,9 @@ void task::add_ratio(ratio new_ratio)
 }
 
 /** add a new ratio at the end of the ratio vector */
-void task::add_ratio(int zaehler, int nenner)
+void task::add_ratio(int numerator, int denominator)
 {
-	ratio new_ratio(zaehler, nenner);
+	ratio new_ratio(numerator, denominator);
 	ratio_vector.push_back(new_ratio);
 	return;
 }
@@ -184,15 +189,15 @@ QTextStream & task::display(QTextStream & str)
 	/* we need this array to look up the fitting chars for the operations */
 	const char a[] = "+-*/";
 
-	/* check, if a qSetW() was given to the stream */
-	int weite = str.width();
+	/* check, if a qSetFieldWidth() was given to the stream */
+	int weite = str.fieldWidth();
 	int pweite = weite;
-	str << qSetW(0);
+	str << qSetFieldWidth(0);
 
 	/* check, if ratio number and operation number fit together */
 	if (ratio_vector.size() != op_vector.size() + 1)
 	{
-		kdDebug() << "Number of ratios and operations do not fit." << endl;
+		kDebug() << "Number of ratios and operations do not fit.";
 		return str;
 	}
 
@@ -203,7 +208,7 @@ QTextStream & task::display(QTextStream & str)
 	for (ratio_pointer = ratio_vector.begin();
 	        ratio_pointer != ratio_vector.end(); ratio_pointer++)
 	{
-		str << qSetW(5) << ratio_pointer->get_zaehler() << "   ";
+		str << qSetFieldWidth(5) << ratio_pointer->numerator() << "   ";
 	}
 	str << endl;
 
@@ -228,8 +233,8 @@ QTextStream & task::display(QTextStream & str)
 	        ratio_pointer != ratio_vector.end(); ratio_pointer++)
 	{
 		if (ratio_pointer == ratio_vector.end() - 1)
-			return str << qSetW(5) << ratio_pointer->get_nenner() << "   ";
-		str << qSetW(5) << ratio_pointer->get_nenner() << "   ";
+			return str << qSetFieldWidth(5) << ratio_pointer->denominator() << "   ";
+		str << qSetFieldWidth(5) << ratio_pointer->denominator() << "   ";
 	}
 	return str;
 }
@@ -251,7 +256,7 @@ ratio task::solve()
 	/* check, if ratio number and operation number fit together */
 	if (ratio_vector.size() != op_vector.size())
 	{
-		kdDebug() << "Number of ratios and operations do not fit." << endl;
+		kDebug() << "Number of ratios and operations do not fit.";
 		return ergebnis;
 	}
 
@@ -295,7 +300,7 @@ ratio task::solve()
 			break;
 
 #ifdef DEBUG
-		kdDebug() << "Schleifenende" << endl;
+		kDebug() << "Schleifenende";
 #endif
 
 	}
@@ -303,7 +308,7 @@ ratio task::solve()
 
 #ifdef DEBUG
 
-	kdDebug() << "after do while in solve()" << endl;
+	kDebug() << "after do while in solve()";
 #endif
 
 	/* if the last operation was an add/sub we haven't add/subed it until now */
@@ -327,6 +332,18 @@ ratio task::solve()
 	return ergebnis; /* return the solution */
 }
 
+/* returns the number of ratios in the vector */
+int task::getNumberOfRatios() const
+{
+	return ratio_vector.count();
+}
+
+/* returns the number of operations in the vector */
+int task::getNumberOfOperations() const
+{
+	return op_vector.count();
+}
+
 /** this function is called by the solving function to compute a given
  * product (or div) and return the solution */
 ratio task::product(RatioArray::iterator & ratio_pointer,
@@ -334,11 +351,11 @@ ratio task::product(RatioArray::iterator & ratio_pointer,
 {
 	/* the function's parameters are pointing to the next ratio;
 	 * to the starting point of the product */
-	ratio product(ratio_pointer->get_zaehler(), ratio_pointer->get_nenner());
+	ratio product(ratio_pointer->numerator(), ratio_pointer->denominator());
 
 #ifdef DEBUG
 
-	kdDebug() << "in product()" << endl;
+	kDebug() << "in product()";
 #endif
 
 	++ratio_pointer;
@@ -471,7 +488,7 @@ int task::make_main_dn(unsigned int pmax_md, unsigned short max_product_length)
 unsigned short task::prim_factor_nr(int number)
 {
 	unsigned int tmp_number = number;
-	primzahl primenumber;
+	primenumber primenumber;
 	Tprime_factor prim_fac_struct;
 
 	/* delete all the prime factors of the old main denominator */
@@ -498,12 +515,12 @@ unsigned short task::prim_factor_nr(int number)
 	}
 #ifdef DEBUG
 	PrimeFactorArray::iterator prim_fac_pointer = prim_fac_vector.begin();
-	kdDebug() << "Primfaktoren von: " << number << endl;
+	kDebug() << "Primfaktoren von: " << number;
 	for (prim_fac_pointer = prim_fac_vector.begin();
 	        prim_fac_pointer != prim_fac_vector.end();
 	        prim_fac_pointer++)
-		kdDebug() << (*prim_fac_pointer).factor << endl;
-	kdDebug() << "Anzahl: " << prim_fac_vector.size() << endl;
+		kDebug() << (*prim_fac_pointer).factor;
+	kDebug() << "Anzahl: " << prim_fac_vector.size();
 #endif
 
 	return prim_fac_vector.size();
@@ -547,7 +564,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 	/* check, if ratio number and operation number fit together */
 	if (ratio_vector.size() != op_vector.size() + 1)
 	{
-		kdDebug() << "Number of ratios and operations do not fit." << endl;
+		kDebug() << "Number of ratios and operations do not fit.";
 		return;
 	}
 
@@ -560,7 +577,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 			tmp_deno = int((double(rand()) / RAND_MAX) * pmax_md) + 1;
 		}
 		while (main_denominator % tmp_deno != 0);
-		(*ratio_pointer).set_nenner(tmp_deno);
+		(*ratio_pointer).setDenominator(tmp_deno);
 	}
 
 	/* if the ratio is connected to a mul or div operation, we have to do some
@@ -582,7 +599,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 				        prim_fac_pointer++)
 					(*prim_fac_pointer).flag = UNUSED;
 
-				/* how many prime factors are avaible? */
+				/* how many prime factors are available? */
 				unused_fac = prim_fac_vector.size() - 1;
 
 				/* now loop through this mul/div section until we find a add/sub */
@@ -613,8 +630,8 @@ void task::make_denominators(int main_denominator, short pmax_md,
 					(*prim_fac_pointer).flag = USED;
 
 					/* store the factor as our new denominator for this ratio */
-					(*ratio_pointer).set_nenner_ohne_k((*prim_fac_pointer).factor);
-					unused_fac--; /* now there is one factor less avaible */
+					(*ratio_pointer).setDenominator((*prim_fac_pointer).factor, false);
+					unused_fac--; /* now there is one factor less available */
 
 					/* move to the next ratio */
 					ratio_pointer++;
@@ -652,8 +669,8 @@ void task::make_denominators(int main_denominator, short pmax_md,
 					(*prim_fac_pointer).flag = USED;
 
 					/* store the factor as our new denominator for this ratio */
-					(*ratio_pointer).set_nenner_ohne_k((*prim_fac_pointer).factor);
-					unused_fac--; /* now there is one factor less avaible */
+					(*ratio_pointer).setDenominator((*prim_fac_pointer).factor, false);
+					unused_fac--; /* now there is one factor less available */
 
 					/* move to the next ratio */
 					ratio_pointer++;
