@@ -97,6 +97,10 @@ protected:
    */
   bool misfullscreen;
 
+  bool mispainting;
+
+  bool malreadyresized;
+
 public:
   /**
    * standard qwidget constructor.  if fullscreen is true, we're a
@@ -105,7 +109,6 @@ public:
   KigWidget( KigPart* doc,
              KigView* view,
              QWidget* parent = 0,
-             const char* name = 0,
              bool fullscreen = false
 	   );
   ~KigWidget();
@@ -131,7 +134,7 @@ public:
    * curPix ), and bitBlt that onto the widget to avoid flickering.
    * TRIPLE BUFFERING:
    * we also currently keep an extra pixmap of what the widget looks
-   * like without objects that are moving... i'm currently wondering
+   * like without objects that are moving... I'm currently wondering
    * whether this isn't a performance loss rather than a gain, but
    * well, i haven't done any measurements (yet ?), so for now it
    * stays in...
@@ -244,9 +247,8 @@ class KigView
 public:
   KigView( KigPart* part,
            bool fullscreen = false,
-	   QWidget* parent = 0,
-	   const char* name = 0
-	   );
+           QWidget* parent = 0
+          );
   ~KigView();
 
   void setupActions();
