@@ -12,8 +12,10 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
+
+#include <math.h>
 
 #include "circle_type.h"
 
@@ -21,6 +23,7 @@
 #include "bogus_imp.h"
 #include "line_imp.h"
 #include "point_imp.h"
+#include "special_imptypes.h"
 
 #include "../misc/common.h"
 
@@ -109,7 +112,7 @@ ObjectImp* CircleBTPType::calc( const Args& args, const KigDocument& ) const
       double d = -(b.x-a.x)/(b.y-a.y);
 
       // length:
-      // sqrt( 3 ) == tan( 60 ) == sqrt( 2^2 - 1^2 )
+      // sqrt( 3 ) == tan( 60° ) == sqrt( 2^2 - 1^2 )
       double l = 1.73205080756 * (a-b).length() / 2;
 
       double d2 = d*d;
@@ -131,7 +134,48 @@ ObjectImp* CircleBTPType::calc( const Args& args, const KigDocument& ) const
   const Coordinate center = calcCenter( a, b, c );
   if ( center.valid() )
     return new CircleImp( center, (center - a ).length() );
-  else return new InvalidImp;
+
+  /*
+   * case of collinear points, we need to identify the intermediate one
+   */
+
+  double xmin = fmin( a.x, fmin( b.x, c.x) );
+  double xmax = fmax( a.x, fmax( b.x, c.x) );
+  double ymin = fmin( a.y, fmin( b.y, c.y) );
+  double ymax = fmax( a.y, fmax( b.y, c.y) );
+  double axy, bxy, cxy;
+
+  /* decide whether to work with x coordinate or y coordinate */
+
+  if ( xmax - xmin > ymax - ymin )
+  {
+    axy = a.x;
+    bxy = b.x;
+    cxy = c.x;
+  } else
+  {
+    axy = a.y;
+    bxy = b.y;
+    cxy = c.y;
+  }
+
+  /*
+   * compute baricentric coordinate of c with respect to a and b
+   * (if a and c are not coincident)
+   */
+  if ( fabs( cxy - axy ) < 1e-6*fabs( bxy - axy ) ) return new InvalidImp;
+  double t = (bxy - axy)/(cxy - axy);
+
+  if ( fabs( t ) < 1e-6  || fabs( 1.0 - t ) < 1e-6 ) return new InvalidImp;
+
+  /*
+   * t < 0:     a between c and b
+   * 0 < t < 1: b between a and c
+   * t > 1:     c between a and b
+   */
+  if ( t < 0.0 ) return new LineImp( c, b );
+  if ( t > 1.0 ) return new LineImp( a, b );
+  return new LineImp( a, c );
 }
 
 const ObjectImpType* CircleBCPType::resultId() const
@@ -146,8 +190,10 @@ const ObjectImpType* CircleBTPType::resultId() const
 
 static const ArgsParser::spec argsspecCircleBPR[] =
 {
-  { PointImp::stype(), "SHOULD NOT BE SEEN", "SHOULD NOT BE SEEN", false },
-  { DoubleImp::stype(), "SHOULD NOT BE SEEN", "SHOULD NOT BE SEEN", false }
+  { PointImp::stype(), constructcirclewithcenterstat,
+      I18N_NOOP( "Select the center of the new circle..." ), false },
+  { &lengthimptypeinstance, I18N_NOOP( "With this radius" ), 
+      I18N_NOOP( "Select the length of the radius..." ), false }
 };
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( CircleBPRType )
@@ -171,7 +217,11 @@ ObjectImp* CircleBPRType::calc( const Args& args, const KigDocument& ) const
 {
   if ( ! margsparser.checkArgs( args ) ) return new InvalidImp;
   const Coordinate c = static_cast<const PointImp*>( args[0] )->coordinate();
-  double r = static_cast<const DoubleImp*>( args[1] )->data();
+  bool valid;
+  double r = getDoubleFromImp( args[1], valid);
+  if ( ! valid ) return new InvalidImp;
+  r = fabs( r );
+  // double r = static_cast<const DoubleImp*>( args[1] )->data();
   return new CircleImp( c, r );
 }
 
