@@ -52,11 +52,6 @@ extern "C" {
 */
 extern void eventLoop(void);
 
-/**
- * \defgroup utilFunctions Utility functions to add and remove callbacks, workprocs, and timers.
- */
-/*@{*/
-
 /** Register a new callback, \e fp, to be called with \e ud as argument when \e fd is ready.
 *
 * \param fd file descriptor.
@@ -101,7 +96,9 @@ extern int addTimer (int ms, TCF *fp, void *ud);
 */
 extern void rmTimer (int tid);
 
-/*@}*/
+/* utility functions */
+extern int deferLoop (int maxms, int *flagp);
+extern int deferLoop0 (int maxms, int *flagp);
 
 #ifdef __cplusplus
 }
