@@ -482,7 +482,6 @@ void KStars::initActions() {
     connect( ta, SIGNAL( triggered() ), this, SLOT( slotViewToolBar() ) );
 
     setXMLFile( "kstarsui.rc" );
-    setupGUI();
 
     if (Options::fitsSaveDirectory().isEmpty())
         Options::setFitsSaveDirectory(QDir:: homePath());
@@ -507,7 +506,7 @@ void KStars::initFOV() {
             QTextStream ostream(&f);
             ostream << i18nc( "Do not use a field-of-view indicator", "No FOV" ) <<  ":0.0:0:#AAAAAA" << endl;
             ostream << i18nc( "use field-of-view for binoculars", "7x35 Binoculars" ) << ":558:1:#AAAAAA" << endl;
-						ostream << i18nc( "use a Telrad field-of-view indicator", "Telrad" ) << ":30:3:#AA0000" << endl;
+            ostream << i18nc( "use a Telrad field-of-view indicator", "Telrad" ) << ":30:3:#AA0000" << endl;
             ostream << i18nc( "use 1-degree field-of-view indicator", "One Degree" ) << ":60:2:#AAAAAA" << endl;
             ostream << i18nc( "use HST field-of-view indicator", "HST WFPC2" ) << ":2.4:0:#AAAAAA" << endl;
             ostream << i18nc( "use Radiotelescope HPBW", "30m at 1.3cm" ) << ":1.79:1:#AAAAAA" << endl;
@@ -726,6 +725,12 @@ void KStars::buildGUI() {
 #else
     createGUI("kstarsui.rc");
 #endif
+    StandardWindowOptions opt = Default;
+    opt &= ~Create;
+    setupGUI(opt); // setupGUI needs to be called after createGUI if no Create flag is passed to
+                   // setupGUI. Once you have called to createGUI you don't want for it to be called
+                   // again. (ereslibre)
+
     //Initialize FOV symbol from options
     data()->fovSymbol.setName( Options::fOVName() );
     data()->fovSymbol.setSize( Options::fOVSize() );
