@@ -15,10 +15,16 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef KSTARSSPLASH_H_
-#define KSTARSSPLASH_H_
+#ifndef KSTARSSPLASH_H__
+#define KSTARSSPLASH_H__
 
-#include <kdialogbase.h>
+#include <QImage>
+#include <QLabel>
+#include <QPaintEvent>
+#include <QCloseEvent>
+
+#include <QDialog>
+//#include <kdialog.h>
 
 /**@class KStarsSplash
 	*The KStars Splash Screen.  The splash screen shows the KStars logo and 
@@ -30,44 +36,36 @@
 
 class QLabel;
 
-class KStarsSplash : public KDialogBase
+class KStarsSplash : public QDialog
 {
-	Q_OBJECT
+    Q_OBJECT
 
-	public:
-	/**Constructor. Create widgets.  Load KStars logo.  Start load timer.
-		*/
-		KStarsSplash( QWidget *parent, const char* name );
+public:
+    /**Constructor. Create widgets.  Load KStars logo.  Start load timer.
+     * A non-empty customMessage will replace "Welcome to KStars [...]".
+    */
+    KStarsSplash( QWidget *parent, const QString& customMessage="" );
 
-	/**Destructor
-		*/
-		~KStarsSplash();
+    /**Destructor
+    	*/
+    ~KStarsSplash();
 
-	public slots:
-	/**Display the text argument in the Splash Screen's status label.
-		*This is connected to KStarsData::progressText(QString)*/
-		void setMessage(QString s);
+public slots:
+    /**Display the text argument in the Splash Screen's status label.
+    	*This is connected to KStarsData::progressText(QString)*/
+    void setMessage(const QString &s);
 
-	protected:
-	/**Paint event to redraw the widgets.  This only gets called when the timer fires.
-		*It should also repaint if another window was on top of the splash screen, but
-		*this may be difficult to implement (it may be that the program is too busy loading data
-		*to notice that a redraw is required).
-		*/
-		virtual void paintEvent( QPaintEvent* );
+protected:
+    /**If the user clicks on the "X" close-window button, then abort loading
+    	*as soon as possible and shut down the program.
+    	*/
+    void closeEvent( QCloseEvent *e );
 
-	/**If the user clicks on the "X" close-window button, then abort loading 
-		*as soon as possible and shut down the program.
-		*/
-		void closeEvent( QCloseEvent *e );
+signals:
+    void closeWindow();
 
-		signals:
-			void closeWindow();
-
-	private:
-		QLabel *textCurrentStatus, *label;
-		QWidget *Banner;
-		QPixmap *splashImage;
+private:
+    QLabel *textCurrentStatus, *label, *Banner;
 };
 
 #endif
