@@ -1,8 +1,8 @@
 /***************************************************************************
                           dlglanguage.h  -  description
                              -------------------
-   copyright            : (C) 2004 by Peter Hedlund
-   email                : peter.hedlund@kdemail.net
+   copyright       : (C) 2004-2006 Peter Hedlund <peter.hedlund@kdemail.net>
+
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,33 +13,27 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- 
+
 #ifndef DLGLANGUAGE_H
 #define DLGLANGUAGE_H
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 
-#include "dlglanguagebase.h"
-
-class KCompletion;
+#include "ui_dlglanguagebase.h"
 
 /**
 @author Peter Hedlund
 */
-class DlgLanguage : public KDialogBase {
-    Q_OBJECT
-  public:
-    DlgLanguage(QWidget *parent = 0, const char *name = 0, bool modal=true);
-    ~DlgLanguage();
+class DlgLanguage : public KDialog {
+  Q_OBJECT
+public:
+  DlgLanguage(QWidget *parent = 0);
 
-    void setLanguage(int index, const QString &lang);
-    QString Language(int index);
-
-  private:
-    DlgLanguageBase *dlgBase;
-    KCompletion * completion1;
-    KCompletion * completion2;
+  void setLanguage(int index, const QString &lang);
+  QString Language(int index);
 
+private:
+  Ui::DlgLanguageBase *dlgBase;
 };
 
 #endif
