@@ -1,7 +1,7 @@
 /***************************************************************************
                           flashview.h -  description
                              -------------------
-   copyright            : (C) 2003 by Peter Hedlund
+   copyright            : (C) 2003-2008 by Peter Hedlund
    email                : peter.hedlund@kdemail.net
  ***************************************************************************/
 
@@ -13,30 +13,27 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- 
+
 #ifndef FLASHVIEW_H
 #define FLASHVIEW_H
 
+#include "ui_flashviewbase.h"
 
+#include <KActionCollection>
 
-#include "flashviewbase.h"
-
-#include "wqscore.h"
-
-class WQQuiz;
+class KWQQuiz;
+class WQScore;
 
 /**
 @author Peter Hedlund
 */
-class FlashView : public FlashViewBase
+class FlashView : public QWidget, public Ui::FlashViewBase
 {
 Q_OBJECT
 public:
-    FlashView(QWidget *parent = 0, const char *name = 0, WFlags f = 0);
+    FlashView(QWidget *parent, KActionCollection *actionCollection);
 
-    ~FlashView();
-
-    void setQuiz(WQQuiz *quiz);
+    void setQuiz(KWQQuiz *quiz);
     void init();
 
 private slots:
@@ -51,14 +48,9 @@ public slots:
     void slotApplySettings();
 
 private:
-    WQQuiz *m_quiz;
+    KWQQuiz *m_quiz;
     WQScore *m_score;
-
-    KAction* actFlip;
-    KAction* actKnow;
-    KAction* actDontKnow;
-    KAction* actRepeat;
-    KAction* actRestart;
+    KActionCollection *m_actionCollection;
 
     QTimer* m_timer;
 
