@@ -43,6 +43,9 @@ PluginManager::PluginManager( QObject *parent )
 
 PluginManager::~PluginManager()
 {
+//    qDeleteAll( d->m_layerPlugins );
+//    d->m_layerPlugins.clear();
+    delete d;
 }
 
 QList<MarbleAbstractFloatItem *> PluginManager::floatItems() const
